# ObjectStorageBucket

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project_id** | **str** |  | 
**data_center_id** | **str** |  | 
**id** | **str** |  | 
**endpoint** | **str** |  | [optional] 
**object_count** | **str** |  | [optional] 
**size_bytes** | **str** |  | [optional] 
**billable_bytes** | **str** |  | [optional] 
**storage_gib_price_hr** | [**Decimal**](Decimal.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


